@@ -23,6 +23,7 @@ import glob
 from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.files import readFile
+import calculate.lib.utils.device as device
 from calculate.lib.utils.common import (getVideoFromXorgLog,
                                         getVideoFromXorgConf,
                                         getVideoFromCmdLine,
@@ -225,8 +226,8 @@ class VariableOsInstallX11VideoDrv(VideoVariable):
             return self.default_video
         else:
             for drv in map(lambda x: x[0], self.choice()):
-                videoSysPath = path.join("/sys/module", drv, "refcnt")
-                refcnt = readFile(videoSysPath).strip()
+                refcnt = device.sysfs.read(
+                    device.sysfs.Path.Module, drv, "refcnt").strip()
                 if refcnt.isdigit() and int(refcnt) > 0:
                     return {'i915': 'intel'}.get(drv, drv)
             else:
@@ -296,7 +297,7 @@ class VariableOsInstallX11Composite(VideoVariable):
 
     def get(self):
         """On/off composite"""
-        defaultCompositeOn = ("nvidia", "intel", "fglrx",  # "amdgpu",
+        defaultCompositeOn = ("nvidia", "intel", "fglrx",  "amdgpu",
                               "nouveau", "radeon", "default")
         composite = getValueFromCmdLine(CmdlineParams.Calculate,
                                         CmdlineParams.Composite)
